@@ -5,15 +5,22 @@ MySQL statements
 """
 
 import math
+import re
 import sys
 from typing import Union
-import re
 
+import nltk
+from nltk.corpus import stopwords
 from dateutil.parser import parse
 
 from .query import db_connect
 
 ################################################################
+try:
+    stopwords.words("english")
+except (LookupError, OSError) as e:
+    nltk.download("stopwords")
+
 kargs_manager = {
     "Single-cell gene expression": "Choose 10X Kit",
     "InDrop": "Choose InDrop Version",
@@ -244,22 +251,27 @@ def sampledata_sql(kwargs: dict) -> None:
 
     # get other ids
     for sample in kwargs["samples"]:
-        query = []
         _labels = [
             ("species_id", "species", "Species", kwargs["samples"][sample]["Species"]),
             ("sampleType_id", "sample_type", "sample_Type", kwargs["Sample type"]),
         ]
-        for _label in _labels:
-            try:
-                query.append(
-                    "SELECT CONCAT('{} ',`id`) FROM {} WHERE {}='{}'".format(*_label)
-                )
-            except AttributeError:
-                pass
-        query = " UNION ".join(query)
-        db_connect.cur.execute(query)
+        query = "SELECT CONCAT('{} ',`id`) FROM {} WHERE {}='{}'"
+        db_connect.cur.execute(query.format(*_labels[0]))
         res = [i[0] for i in db_connect.cur.fetchall()]
-        if res:
+        for i in res:
+            k, v = i.split()
+            kwargs["samples"][sample][k] = v
+        db_connect.cur.execute(query.format(*_labels[1]))
+        res = [i[0] for i in db_connect.cur.fetchall()]
+        if not res:
+            db_connect.cur.execute(
+                "INSERT INTO `sample_type` (`sample_Type`) VALUES "
+                "('{}')".format(kwargs["Sample type"])
+            )
+            db_connect.cur.execute("SELECT LAST_INSERT_ID()")
+            sampleType_id = [i[0] for i in db_connect.cur.fetchall()][0]
+            kwargs["samples"][sample]["sampleType_id"] = sampleType_id
+        else:
             for i in res:
                 k, v = i.split()
                 kwargs["samples"][sample][k] = v
@@ -395,6 +407,40 @@ def projectdata_sql(kwargs: dict) -> str:
     :return:
         MySQL statement
     """
+    # A set of common expressions to abbreviate
+    # Order is important
+    abbrv = {
+        "Characterization": "Character",
+        "Comparison": "Comp",
+        "Conditions": "Cond",
+        "Number": "Num",
+        "Development": "Dev",
+        "Differentiation": "Diff",
+        "Education": "Edu",
+        "Enrichment": "Enrich",
+        "Evolution": "Evol",
+        "Experimental": "Exp",
+        "Experiments": "Exp",
+        "Expression": "Expr",
+        "Memory": "Mem",
+        "Metastasis": "Met",
+        "Environmental": "Env",
+        "Normal": "Norm",
+        "Optimization": "Optim",
+        "Population": "Pop",
+        "Primary": "Pri",
+        "project": "Prj",
+        "Regeneration": "Regen",
+        "Sequencing": "Seq",
+        "SingleCell": "sc",
+        "Rna": "RNA",
+        "RNASeq": "RNAseq",
+        "Crc": "CRC",
+        "Tcr": "TCR",
+        "Csf": "CSF",
+        "Cite": "CITE",
+        "CITESeq": "CITEseq",
+    }
     # first check if lab exists in the database:
     query = "SELECT `id` FROM lab WHERE PI_name=%(PI_name)s COLLATE utf8mb4_bin"
     db_connect.cur.execute(query, kwargs)
@@ -434,7 +480,7 @@ def projectdata_sql(kwargs: dict) -> str:
     query = (
         "SELECT `id` FROM project_data WHERE request_id=%s"
         " UNION "
-        "SELECT `id` FROM project_data WHERE projectShortNAme=%s COLLATE utf8mb4_bin"
+        "SELECT `id` FROM project_data WHERE projectName=%s COLLATE utf8mb4_bin"
     )
     db_connect.cur.execute(
         query, (kwargs["request_id"], kwargs["Provide a short project name"])
@@ -447,19 +493,34 @@ def projectdata_sql(kwargs: dict) -> str:
     regex = re.compile(r"[\\&$@=;:.+,?}{^%`\]\[<>~#|/]")
     try:
         assert (
-            len(kwargs["Provide a short project name"]) <= 30
-            and regex.findall(kwargs["Provide a short project name"]) == []
+            regex.findall(kwargs["Provide a short project name"]) == []
         ), "Validation failed for project Name!"
     except AssertionError as e:
         print(str(e))
-        if len(kwargs["Provide a short project name"]) > 30:
-            print("Project name exceeded the allowed number of 30 characters!")
         if regex.findall(kwargs["Provide a short project name"]):
             print(
                 "Project name has undesired characters:",
                 regex.findall(kwargs["Provide a short project name"]),
             )
         sys.exit("Fix the project name and try again.")
+    else:
+        # generate a project short name
+        stop_words = set(stopwords.words("english"))
+        tokenizer = nltk.RegexpTokenizer(r"\w+")
+        # keep only words
+        tokens = tokenizer.tokenize(kwargs["Provide a short project name"].lower())
+        # remove stop words
+        projShortName = [w for w in tokens if w not in stop_words]
+        # reformat and keep only alphanumeric characters
+        projShortName = [
+            "".join(e for e in string.title() if e.isalnum())
+            for string in projShortName
+        ]
+        projShortName = "".join(projShortName)
+        # iterate through common words to abbreviate
+        for k, v in abbrv.items():
+            projShortName = re.sub(k, v, projShortName)
+        kwargs["projShortName"] = projShortName
 
     # insert new project to database
     _columns = [
@@ -474,7 +535,7 @@ def projectdata_sql(kwargs: dict) -> str:
     ]
     _labels = [
         "Provide a short project name",
-        "Provide a short project name",
+        "projShortName",
         "request_id",
         "Project label",
         "date_created",
@@ -695,9 +756,9 @@ def statsdata_sql(kwargs: dict) -> None:
             for label, column in zip(_labels, _columns):
                 try:
                     if kwargs["samples"][sample]["hashtag_parameters"][label] != "NULL":
-                        kargs_[column] = kwargs["samples"][sample]["hashtag_parameters"][
-                            label
-                        ]
+                        kargs_[column] = kwargs["samples"][sample][
+                            "hashtag_parameters"
+                        ][label]
                 except KeyError:
                     pass
             kargs_["Sample"] = sample + "_" + kargs_["Sample"]
