@@ -1,27 +1,43 @@
 #!/usr/bin/env python3
 
-import os
-import sys
-import re
 import datetime
 import fnmatch
-import shlex
 import hashlib
-import urllib.parse
-import subprocess
-import logging
-from typing import Union, Tuple, Iterable, Optional, Dict, List
-from collections import namedtuple, ChainMap
-
 import json
-import yaml
+import logging
+import os
+import re
+import shlex
+import subprocess
+import sys
+import urllib.parse
+from collections import ChainMap, namedtuple
+from typing import Dict, Iterable, List, Optional, Tuple, Union
+
 import boto3
-import mysql
 import numpy as np
 import pandas as pd
+import yaml
 
 from .query import db_connect
 
+di = {
+    "ten_x_v2": 1,
+    "ten_x_v3": 1,
+    "H3": 2,
+    "H2": 2,
+    "H4": 2,
+    "CiteSeq": 3,
+    "VDJ": 4,
+    "five_prime": 5,
+    "ATAC": 6,
+    "CR": 7,
+    "in_drop_v2": 8,
+    "in_drop_v4": 8,
+    "in_drop_v5": 8,
+    "multiome": 9,
+}
+
 
 def sample_fun(x: str) -> str:
     """\
@@ -367,7 +383,8 @@ def sample_data_frame(sd: pd.DataFrame) -> pd.DataFrame:
             logging.warning(msg)
             samples = samples[mask]
         for s, o, id in zip(samples, np.array(old_basename)[mask], arr):
-            if "HTO" in str(id):
+            # TODO: CITE
+            if "HTO" in str(id) or "CITE" in str(id):
                 q = (
                     "SELECT "
                     "a.id, h.Sample, a.projectData_id, h.genomeIndex_id, "
@@ -507,9 +524,7 @@ def sample_data_frame(sd: pd.DataFrame) -> pd.DataFrame:
     sample_data["label"] = sample_data["label"].map(table_dict)
 
     sample_data["source"] = (
-        "/"
-        + sample_data["project_loc"].str.cat(sample_data["old_basename"], sep="/")
-        + "/"
+        sample_data["project_loc"].str.cat(sample_data["old_basename"], sep="/") + "/"
     )
     sample_data["s3uri"] = (
         sample_data["s3_loc"].str.cat(sample_data["sample"], sep="/") + "/"
@@ -519,22 +534,6 @@ def sample_data_frame(sd: pd.DataFrame) -> pd.DataFrame:
     )
     sample_data["igo_id"] = sample_data.igo_id.str.split(pat="/", n=1, expand=True)[0]
 
-    di = {
-        "ten_x_v2": 1,
-        "ten_x_v3": 1,
-        "H3": 2,
-        "H2": 2,
-        "H4": 2,
-        "CiteSeq": 3,
-        "VDJ": 4,
-        "five_prime": 5,
-        "ATAC": 6,
-        "CR": 7,
-        "in_drop_v2": 8,
-        "in_drop_v4": 8,
-        "in_drop_v5": 8,
-        "multiome": 9,
-    }
     sample_data["platform"] = "NULL"
     sample_data["platform"] = sample_data["run_name"].map(di)
 
@@ -556,20 +555,6 @@ def prepare_statements(sample_data: pd.DataFrame) -> dict:
         cmd = []
         root_source = os.path.join(sample_.project_loc, sample_.old_basename, "")
         data_storage = os.path.join(sample_.s3_loc, sample_.sample, "")
-        if sample_.label != "sample_data":
-            whereid = "sampleData_id"
-        else:
-            whereid = "id"
-        if sample_.label == "hashtag_lib":
-            h_status = ", `status`=2"
-        else:
-            h_status = ""
-        statement = (
-            "UPDATE {} SET AWS_storage='{}', source_path='{}'{} WHERE {}="
-            "{}".format(
-                sample_.label, data_storage, root_source, h_status, whereid, sample_.id
-            )
-        )
 
         if root_source.startswith("s3://"):
             list_files = get_bucket_contents(root_source)
@@ -616,9 +601,10 @@ def prepare_statements(sample_data: pd.DataFrame) -> dict:
                     _, bucket, key, _, _ = urllib.parse.urlsplit(target_genomic)
                     cmd.append([bucket, key.strip("/"), source_genomic])
 
-        sample_set[str(sample_.id) + "_" + sample_.label] = dict(
-            cmd=cmd, statement=statement
-        )
+        # sample_set[str(sample_.id) + "_" + sample_.label] = dict(
+        #     cmd=cmd, statement=statement
+        # )
+        sample_set[str(sample_.id) + "_" + sample_.label] = dict(cmd=cmd)
 
     return sample_set
 
@@ -775,7 +761,7 @@ def copy_files_to_processing_folder(sample_data: pd.DataFrame, **kwargs) -> List
                     failed_samples.append(str(key.split("_")[0]))
                     logging.warning("Fix the missing dates and try again..")
                 else:
-                    success_list = []
+                    # success_list = []
                     for cmd in sample_set[key]["cmd"]:
                         dest_bucket_name, dest_object_name, src_data = cmd
                         msg, success = put_object(
@@ -784,23 +770,9 @@ def copy_files_to_processing_folder(sample_data: pd.DataFrame, **kwargs) -> List
                             src_data,
                             kwargs["md5sums"],
                         )
-                        if success:
-                            success_list.append(success)
-                        else:
+                        if not success:
                             failed_samples.append(str(key))
-                    if all(success_list):
-                        try:
-                            db_connect.cur.execute(sample_set[key]["statement"])
-                            print(db_connect.cur.statement)
-                        except mysql.connector.Error as err:
-                            print(
-                                "Something went wrong with sample {}: {}".format(
-                                    key.split("_")[0], err
-                                )
-                            )
-                            db_connect.db.rollback()
-                        finally:
-                            db_connect.db.commit()
+
     return failed_samples
 
 
